@@ -4,9 +4,9 @@ Universal wrapper for Python functions to be used with LLM function calling.
 :see: https://github.com/hunyadi/function_tool
 """
 
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 __author__ = "Levente Hunyadi"
-__copyright__ = "Copyright 2025, Levente Hunyadi"
+__copyright__ = "Copyright 2025-2026, Levente Hunyadi"
 __license__ = "MIT"
 __maintainer__ = "Levente Hunyadi"
 __status__ = "Production"
@@ -57,8 +57,7 @@ class GenerateJsonSchemaNoTitles(GenerateJsonSchema):
 class ToolBaseModel(BaseModel):
     "Disables generating `additionalProperties` in JSON schema to ensure compliance with OpenAI's function tool calling convention."
 
-    class Config:
-        extra = "forbid"
+    model_config = ConfigDict(extra="ignore", json_schema_extra={"additionalProperties": False})
 
 
 B = TypeVar("B", bound=ToolBaseModel)
